package net.thecodersbreakfast.generics.fluent;

public class BasicQueryBuilder<T extends BasicQueryBuilder<?>> {

	protected StringBuilder buf = new StringBuilder();

	public String getQuery() {
		return buf.toString();
	}

	public T select(String... fields) {
		buf.append("SELECT ");
		buf.append(join(", ", fields));
		return (T) this;
	}

	public T from(String... tables) {
		buf.append("\nFROM ");
		buf.append(join(", ", tables));
		return (T) this;
	}

	public T where(String... criteria) {
		buf.append("\nWHERE ");
		buf.append(join(" and ", criteria));
		return (T) this;
	}

	protected String join(String separator, Object... objects) {
		StringBuilder builder = new StringBuilder();
		boolean first = true;
		for (Object o : objects) {
			if (first) {
				first = false;
			} else {
				builder.append(separator);
			}
			builder.append(o);
		}
		return builder.toString();
	}

}
